/* eslint-disable import/no-mutable-exports */
/**
 * The builder aka file bundler.
 * @privateRemarks
 * Provided by default as part of the `resolveDefineConfig` in the build kit.
 * @example 'webpack', 'vite'.
 * @defaultValue `'webpack'`
 * @public
 */
let _BUILDER = 'webpack';
try {
    if (typeof BUILDER !== 'undefined') {
        _BUILDER = BUILDER;
    }
}
catch (_a) { }
export { _BUILDER as BUILDER };
/**
 * The public path.
 * @privateRemarks
 * Provided by default as part of the `resolveDefineConfig` in the build kit.
 * @example '/', '/app/'.
 * @public
 * @defaultValue `'/'`
 */
let _PUBLIC_PATH = '/';
try {
    if (typeof PUBLIC_PATH !== 'undefined') {
        _PUBLIC_PATH = PUBLIC_PATH;
    }
}
catch (_b) { }
export { _PUBLIC_PATH as PUBLIC_PATH };
/**
 * The sub-path used for WebSocket connections when API_HOST is not set
 * @public
 * @defaultValue `'gwf'`
 * @remarks Optional.
 * @example
 * If `API_HOST` is not set, `SOCKET_EXT` is set to `/custom` and UI is served on `https://localhost:1234`
 * API host URL will be `wss://localhost:1234/custom`
 */
let _SOCKET_EXT = 'gwf';
try {
    if (typeof SOCKET_EXT !== 'undefined') {
        _SOCKET_EXT = SOCKET_EXT;
    }
}
catch (_c) { }
export { _SOCKET_EXT as SOCKET_EXT };
/**
 * The path to a JSON config file for the HTTP mode.
 * @remarks Optional.
 * @public
 */
let _FORCE_HTTP;
try {
    _FORCE_HTTP = FORCE_HTTP;
}
catch (_d) { }
export { _FORCE_HTTP as FORCE_HTTP };
/**
 * Genesis Socket URL
 * @remarks
 * Built from the current {@link https://developer.mozilla.org/en-US/docs/Web/API/Location} object and {@link SOCKET_EXT | socket extension}.
 * @example
 * ```ts
 * await this.connect.connect(GENESIS_SOCKET_URL); // < wss://localhost:6060/gwf/
 * ```
 * @public
 */
export const GENESIS_SOCKET_URL = `${location.protocol.replace('http', 'ws')}//${location.host}/${_SOCKET_EXT}/`;
const PROTOCOL = _FORCE_HTTP === 'true' ? location.protocol : location.protocol.replace('http', 'ws');
/**
 * The Genesis Server URL (WebSocket or HTTP).
 * @remarks Optional.
 * @defaultValue `${PROTOCOL}//${location.host}/${_SOCKET_EXT}/`
 * @example ws://localhost/gwf/, ws://localhost:9064
 * @public
 */
let _API_HOST = `${PROTOCOL}//${location.host}/${_SOCKET_EXT}/`;
try {
    if (typeof API_HOST !== 'undefined') {
        _API_HOST = API_HOST;
    }
}
catch (_e) { }
export { _API_HOST as API_HOST };
/**
 * Configuration settings for HTTP, used in http connect flow [`genesislcap-foundation-comms.HttpConnectConfig`](https://link-to-docs).
 * @remarks Optional.
 * @public
 */
let _HTTP_CONFIG;
try {
    _HTTP_CONFIG = HTTP_CONFIG;
}
catch (_f) { }
export { _HTTP_CONFIG as HTTP_CONFIG };
/**
 * The default Organisation value, used in auth/login flow [`genesislcap-foundation-login`](https://link-to-docs).
 * @remarks Optional.
 * @public
 */
let _DEFAULT_ORGANISATION;
try {
    _DEFAULT_ORGANISATION = DEFAULT_ORGANISATION;
}
catch (_g) { }
export { _DEFAULT_ORGANISATION as DEFAULT_ORGANISATION };
/**
 * The default Password value, used in auth/login flow [`genesislcap-foundation-login`](https://link-to-docs).
 * @remarks Optional.
 * @public
 */
let _DEFAULT_PASSWORD;
try {
    _DEFAULT_PASSWORD = DEFAULT_PASSWORD;
}
catch (_h) { }
export { _DEFAULT_PASSWORD as DEFAULT_PASSWORD };
/**
 * The default Username value, used in auth/login flow [`genesislcap-foundation-login`](https://link-to-docs).
 * @remarks Optional.
 * @public
 */
let _DEFAULT_USER;
try {
    _DEFAULT_USER = DEFAULT_USER;
}
catch (_j) { }
export { _DEFAULT_USER as DEFAULT_USER };
